; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "orenonada"
command = ~F, $D, B, F, b
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "p.mist"
command = ~D, DF, F, x

[Command]
name = "k.mist"
command = ~D, DF, F, a

[Command]
name = "s.mist"
command = ~D, DF, F, y

[Command]
name = "glitter"
command = ~D, DF, F, b

[Command]
name = "bacchus"
command = ~D, DB, B, x

[Command]
name = "divine"
command = ~F, D, DF, y

[Command]
name = "a.divine"
command = ~D, DF, F, y

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+a

[Command]
name = "faultless"
command = /$B, x+a

[Command]
name = "d.a.a."
command = F, x+a

[Command]
name = "dust"
command = y+b

[Command]
name = "dust"
command = c

;-| Dir + Button |---------------------------------------------------------
;[Command]
;name = "down_a"
;command = /$D,a
;time = 1

;[Command]
;name = "down_b"
;command = /$D,b
;time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "kick"
command = a
time = 1

[Command]
name = "hslash"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "punch"
command = x
time = 1

[Command]
name = "slash"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "hjump"
command = ~$D, $U
time = 5

[Command]
name = "up"
command = $U
time = 1

;------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1
;------------

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[command]
name = "holdpunch"
command = /x
time = 1

[command]
name = "holdkick"
command = /a
time = 1

[command]
name = "holdslash"
command = /y
time = 1

;--%%%----------------------------------------------------------------------

[Statedef -1]

[State -1, !]
type = ChangeState
value = 3000
triggerall = command = "orenonada"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,235]
trigger2 = stateno != 205 && stateno != 215
trigger2 = movecontact
trigger3 = stateno = [400,440]
trigger3 = movecontact

[State -1, glit]
type = ChangeState
value = 1600
triggerall = command = "glitter"
triggerall = var(8) > 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,235]
trigger2 = stateno != 205 && stateno != 215
trigger2 = movecontact
trigger3 = stateno = [400,440]
trigger3 = movecontact

[State -1, sigh]
type = ChangeState
value = 1700
triggerall = command = "bacchus"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,235]
trigger2 = stateno != 205 && stateno != 215
trigger2 = movecontact
trigger3 = stateno = [400,440]
trigger3 = movecontact

;---------------------------------------------------------------------------

[state -1, asd]
type = changestate
value = 1500
triggerall = command = "a.divine"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = [600,630]
trigger2 = movecontact

[state -1, asd]
type = changestate
value = 1501
triggerall = command = "divine"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,235]
trigger2 = stateno != 205 && stateno != 215
trigger2 = movecontact
trigger3 = stateno = [400,440]
trigger3 = movecontact

;------------------------------------
[State -1, finer p]
type = ChangeState
value = 1000
triggerall = command = "p.mist"
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = var(10) := 1
trigger2 = stateno = [200,235]
trigger2 = stateno != 205 && stateno != 215
trigger2 = movecontact
trigger2 = var(10) := 1
trigger3 = stateno = [400,440]
trigger3 = movecontact
trigger3 = var(10) := 1

[State -1, finer k]
type = ChangeState
value = 1000
triggerall = command = "k.mist"
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = (var(10) := 0)|1
trigger2 = stateno = [200,235]
trigger2 = stateno != 205 && stateno != 215
trigger2 = movecontact
trigger2 = (var(10) := 0)|1
trigger3 = stateno = [400,440]
trigger3 = movecontact
trigger3 = (var(10) := 0)|1

[State -1, finer s]
type = ChangeState
value = 1000
triggerall = command = "s.mist"
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = var(10) := 2
trigger2 = stateno = [200,235]
trigger2 = stateno != 205 && stateno != 215
trigger2 = movecontact
trigger2 = var(10) := 2
trigger3 = stateno = [400,440]
trigger3 = movecontact
trigger3 = var(10) := 2

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------

;ADash Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 7000
trigger1 = command = "FF"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = (var(4) & 3) != 1
trigger1 = var(4) := var(4) + 1
trigger1 = (var(10):=0)|1

;---------------------------------------------------------------------------
;ADash Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 7000
trigger1 = command = "BB"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = (var(4) & 3) != 1
trigger1 = var(4) := var(4) + 1
trigger1 = (var(10):=1)

;-------------------------------------
; jcancel

[state -1]
type = changestate
value = ifelse(statetype = A, 45, 40)
trigger1 = p2statetype = A
trigger1 = (stateno = 620) || (stateno = [200,230]) || (stateno = [400,430])
trigger1 = movecontact
trigger1 = command = "up"
trigger1 = (var(4) & 12) != 4
trigger1 = var(4) := var(4) + 4

;-------------------------------------
; hjump

[state -1]
type = changestate
value = 7040
trigger1 = command = "hjump"
trigger1 = statetype != A
trigger1 = ctrl

;-------------------------------------
; a-dash disable set/reset

[state -1] ;reset
type = varset
trigger1 = movetype = H
trigger2 = statetype != A
var(4) = 0

[state -1] ;set
type = varset
trigger1 = stateno = 45
trigger1 = (var(4) & 3) != 1
var(4) = var(4) + 1

;---------------------------------------------------------------------------
; ukemi

[state -1]
type = changestate
trigger1 = stateno = 5050
trigger1 = command = "recovery"
trigger1 = vel Y >= 1
trigger1 = alive
value = 5210

;---------------------------------------------------------------------------
; d.a.a.

[state -1]
type = changestate
trigger1 = command = "d.a.a."
trigger1 = stateno = [150,153] 
trigger1 = power >= 1000
value = 206
ignorehitpause = 1

;---------------------------------------------------

;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 290
triggerall = command = "hslash"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
; fwd attacks

[State -1, fPunch]
type = ChangeState
value = 205
triggerall = command = "punch"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl

[State -1, fKick]
type = ChangeState
value = 215
triggerall = command = "kick"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl

[State -1, fHSlash]
type = ChangeState
value = 235
triggerall = command = "hslash"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 220
trigger2 = movecontact

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch

[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "punch"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = movecontact || animelemno(0) >= 3

;---------------------------------------------------------------------------

[State -1, Stand kick]
type = ChangeState
value = 210
triggerall = command = "kick"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210 
trigger2 = movecontact

;---------------------------------------------------------------------------

[State -1, near slash]
type = ChangeState
value = 225
triggerall = command = "slash"
triggerall = command != "holddown"
triggerall = p2bodydist x < 30
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210 
trigger2 = movecontact

[State -1, Stand slash]
type = ChangeState
value = 220
triggerall = command = "slash"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210
trigger2 = movecontact

;---------------------------------------------------------------------------

[State -1, Standing hslash]
type = ChangeState
value = 230
triggerall = command = "hslash"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210 || stateno = 225 
trigger2 = movecontact
trigger3 = stateno = 400 || stateno = 410 || stateno = 420 
trigger3 = movecontact

;---------------------------------------------------------------------------

[State -1, Taunt]
type = ChangeState
value = ifelse(command = "holdfwd", 196, 195)
;value = 196
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------

[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "punch"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = movecontact
trigger3 = stateno = 400
trigger3 = movecontact || animelemno(0) >= 3

;---------------------------------------------------------------------------
;Crouching kick
;Ⴊ݋p`
[State -1, Crouching kick]
type = ChangeState
value = 410
triggerall = command = "kick"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210
trigger2 = movecontact
trigger3 = stateno = 400 || stateno = 410
trigger3 = movecontact

;---------------------------------------------------------------------------

[State -1, sdjkhfs]
type = ChangeState
value = 440
triggerall = command = "dust"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210 || stateno = 220
trigger2 = movecontact
trigger3 = stateno = 400 || stateno = 410 || stateno = 420
trigger3 = movecontact

;---------------------------------------------------------------------------

[State -1, Crouching slash]
type = ChangeState
value = 420
triggerall = command = "slash"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210 || stateno = 220
trigger2 = movecontact
trigger3 = stateno = 400 || stateno = 410
trigger3 = movecontact

;---------------------------------------------------------------------------

[State -1, Crouching hslash]
type = ChangeState
value = 430
triggerall = command = "hslash"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 210 || stateno = 220
trigger2 = movecontact
trigger3 = stateno = 400 || stateno = 410 || stateno = 420
trigger3 = movecontact


;---------------------------------------------------------------------------
;Jump Light Punch
;
[State -1, Jump Punch]
type = ChangeState
value = 600
triggerall = command = "punch"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
; jk
[State -1, Jump Kick]
type = ChangeState
value = 610
triggerall = command = "kick"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 
trigger2 = movecontact

;---------------------------------------------------------------------------
; js
[State -1, Jump slash]
type = ChangeState
value = 620
triggerall = command = "slash"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610  
trigger2 = movecontact

;---------------------------------------------------------------------------
; jhs
[State -1, Jump hslash]
type = ChangeState
value = 630
triggerall = command = "hslash"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610; || stateno = 630 
trigger2 = movecontact

; tests
[state -1]
type = null;explod
trigger1 = command = "start"
anim = 3100
pos = 160, 200
postype = left
facing = 1
ontop = 1

